/*
 * ========================================================================
 *
 * Codehaus CARGO, copyright 2004-2010 Vincent Massol.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * ========================================================================
 */
package org.codehaus.cargo.container.configuration.entry;

import org.codehaus.cargo.container.LocalContainer;

/**
 * Designates a {@link LocalContainer container} supports {@link Resource resource} configuration.
 * The operations in this interface should not depend on prior state and should be able to be called
 * multiple times.
 * 
 * @version $Id: ResourceSupport.java 2340 2010-07-02 09:05:39Z alitokmen $
 */
public interface ResourceSupport
{
    /**
     * @param ds the Resource configuration you wish to install on the container.
     * @param container the container whose configuration you wish to affect.
     */
    void configure(Resource ds, LocalContainer container);

    /**
     * Configure the Resources defined for this configuration.
     * 
     * @param container the container whose configuration you wish to affect.
     */
    void configureResources(LocalContainer container);

}
